==> service-proxy-core-4.6.3-sources.jar: com/predic8/membrane/core/http/xml/Port.java <==
/* Copyright 2009, 2011 predic8 GmbH, www.predic8.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. */
package com.predic8.membrane.core.http.xml;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import com.predic8.membrane.core.config.AbstractXmlElement;

public class Port extends AbstractXmlElement {
	public static final String ELEMENT_NAME = "port";

	int value;

	public Port(int port) {
		value = port;
	}

	public Port() {

	}

	@Override
	protected void parseCharacters(XMLStreamReader token) throws XMLStreamException {
		value = Integer.valueOf(token.getText());
	}

	@Override
	public void write(XMLStreamWriter out) throws XMLStreamException {
		out.writeStartElement(ELEMENT_NAME);
		out.writeCharacters(""+value);
		out.writeEndElement();
	}

	public int getValue() {
		return value;
	}

	public void setValue(int value) {
		this.value = value;
	}

	@Override
	protected String getElementName() {
		return ELEMENT_NAME;
	}

}

==> service-proxy-core-5.1.0-sources.jar: com/predic8/membrane/core/http/xml/Port.java <==
/* Copyright 2009, 2011 predic8 GmbH, www.predic8.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. */
package com.predic8.membrane.core.http.xml;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import com.predic8.membrane.core.config.AbstractXmlElement;

public class Port extends AbstractXmlElement {
	public static final String ELEMENT_NAME = "port";

	int value;

	public Port(int port) {
		value = port;
	}

	public Port() {

	}

	@Override
	protected void parseCharacters(XMLStreamReader token) throws XMLStreamException {
		value = Integer.parseInt(token.getText());
	}

	@Override
	public void write(XMLStreamWriter out) throws XMLStreamException {
		out.writeStartElement(ELEMENT_NAME);
		out.writeCharacters(""+value);
		out.writeEndElement();
	}

	public int getValue() {
		return value;
	}

	public void setValue(int value) {
		this.value = value;
	}

	@Override
	protected String getElementName() {
		return ELEMENT_NAME;
	}

}
